# Another posixpath module, supports names that contain backslashes.

## Installation

You can install from [pypi](https://pypi.org/project/posixpatht/)

```console
pip install -U posixpatht
```

## Usage

```python
import posixpatht
```
